# Get started

The BlocksNet library can be installed with `pip` right from the jupyter notebook cell. But if you have to setup the environment please check the advanced guides on how to proceed with the library:

```{toctree}
:maxdepth: 2

windows/index
linux/index
```

```{include} ../../../README.md
:start-after: <!-- installation-start -->
:end-before: <!-- installation-end -->
```

```{include} ../../../README.md
:start-after: <!-- use-start -->
:end-before: <!-- use-end -->
```
